# coding: utf-8

"""
    Arthur Scope

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from arthur_client.api_bindings.models.numeric_time_series import NumericTimeSeries

class TestNumericTimeSeries(unittest.TestCase):
    """NumericTimeSeries unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> NumericTimeSeries:
        """Test NumericTimeSeries
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `NumericTimeSeries`
        """
        model = NumericTimeSeries()
        if include_optional:
            return NumericTimeSeries(
                dimensions = [
                    arthur_client.api_bindings.models.dimension.Dimension(
                        name = '', 
                        value = '', )
                    ],
                values = [
                    arthur_client.api_bindings.models.numeric_point.NumericPoint(
                        timestamp = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        value = 1.337, )
                    ]
            )
        else:
            return NumericTimeSeries(
                dimensions = [
                    arthur_client.api_bindings.models.dimension.Dimension(
                        name = '', 
                        value = '', )
                    ],
                values = [
                    arthur_client.api_bindings.models.numeric_point.NumericPoint(
                        timestamp = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        value = 1.337, )
                    ],
        )
        """

    def testNumericTimeSeries(self):
        """Test NumericTimeSeries"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
